pub trait ToString {
// Required method
fn to_string(&self) -> String ⓘ;
}Available on crate feature
alloc only.Expand description
𝐓
alloc
A trait for converting a value to a String.
Re-exported from alloc::string::
.
A trait for converting a value to a String.
This trait is automatically implemented for any type which implements the
Display trait. As such, ToString shouldn’t be implemented directly:
Display should be implemented instead, and you get the ToString
implementation for free.